@@ -37,6 +37,10 @@ sub mysql_make_schema
 			 precision => 2,
 			 nullable => 1,
 		       );
+    $emp_t->make_column( name => 'tstamp',
+			 type => 'integer',
+			 nullable => 1,
+		       );
     $emp_t->make_index( columns => [ { column => $emp_t->column('name'),
 				       prefix => 10 },
 				     { column => $emp_t->column('smell') },
@@ -147,6 +151,10 @@ sub pg_make_schema
 			 precision => 2,
 			 nullable => 1,
 		       );
+    $emp_t->make_column( name => 'tstamp',
+			 type => 'integer',
+			 nullable => 1,
+		       );
     $emp_t->make_index( columns => [ { column => $emp_t->column('name') } ] );
 
     $s->make_table( name => 'department');
